/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import * as Comlink from "comlink";
/**
 * Proxies requests to web worker loader.
 */
export class WebWorkerLoader {
    constructor(proxy) {
        this.proxy = proxy;
    }
    static async load(id, options, resolved, fromSequenceNumber) {
        const ProxyLoader = Comlink.wrap(new Worker("/public/scripts/dist/worker.min.js"));
        const proxyLoader = await new ProxyLoader(id, options, resolved, fromSequenceNumber);
        return new WebWorkerLoader(proxyLoader);
    }
    get IFluidRouter() { return this; }
    get IFluidRunnable() { return this; }
    async request(request) {
        const response = await this.proxy.request(request);
        if (response.status !== 200 || response.mimeType !== "fluid/object") {
            return response;
        }
        return { status: 200, mimeType: "fluid/object", value: this };
    }
    async run(...args) {
        return this.proxy.run(...args);
    }
    async stop(reason) {
        return this.proxy.stop(reason);
    }
    async resolve(request, pendingLocalState) {
        return this.proxy.resolve(request, pendingLocalState);
    }
    async createDetachedContainer(source) {
        return this.proxy.createDetachedContainer(source);
    }
    async rehydrateDetachedContainerFromSnapshot(source) {
        return this.proxy.rehydrateDetachedContainerFromSnapshot(source);
    }
}
//# sourceMappingURL=webWorkerLoader.js.map